Whisker Python client library
=============================

Python package for Whisker clients.

By Rudolf Cardinal (rudolf@pobox.com)

Install with ``pip install whisker``.

Documentation is at https://whiskerpythonclient.readthedocs.io/.
